@@ -85,7 +85,7 @@ def load(path, tag_version=None):
 
 class AudioInfo(object):
     """A base container for common audio details."""
-    time_secs = 0
+    time_secs = 0.0
     """The number of seconds of audio data (i.e., the playtime)"""
     size_bytes = 0
     """The number of bytes of audio data."""
@@ -282,7 +282,7 @@ class Date(object):
                           "%Y-%m-%d %H:%M:%S",
                           "%Y-00-00",
                          ]
-    """Valid time stamp formats per ISO 8601 and used by \c strptime."""
+    """Valid time stamp formats per ISO 8601 and used by `strptime`."""
 
     def __init__(self, year, month=None, day=None,
                  hour=None, minute=None, second=None):
