@@ -618,10 +618,7 @@ class ImageFrame(Frame):
         # some code has problems with image descriptions encoded <> latin1
         # namely mp3diags: work around the problem by forcing latin1 encoding
         # for empty descriptions, which is by far the most common case anyway
-        if self.description:
-            self._initEncoding()
-        else:
-            self.encoding = LATIN1_ENCODING
+        self._initEncoding()
 
         if not self.image_data and self.image_url:
             self._mime_type = self.URL_MIME_TYPE
@@ -1019,7 +1016,7 @@ class UniqueFileIDFrame(Frame):
         log.debug("UFID owner_id: %s" % self.owner_id)
         log.debug("UFID id: %s" % self.uniq_id)
         if len(self.owner_id) == 0:
-            dummy_owner_id = "http://www.id3.org/dummy/ufid.html"
+            dummy_owner_id = b"http://www.id3.org/dummy/ufid.html"
             self.owner_id = dummy_owner_id
             core.parseError(FrameException("Invalid UFID, owner_id is empty. "
                                            "Setting to '%s'" % dummy_owner_id))
