@@ -34,3 +34,19 @@ def id3tag():
 def image(tmpdir):
     img_file = _tempCopy(DATA_D / "CypressHill3TemplesOfBoom.jpg", tmpdir)
     return img_file
+
+
+@pytest.fixture(scope="session")
+def eyeD3():
+    from eyed3 import main
+    def func(audiofile, args, expected_retval=0, reload_version=None):
+        try:
+            args, _, config = main.parseCommandLine(args + [audiofile.path])
+            retval = main.main(args, config)
+        except SystemExit as exit:
+            retval = exit.code
+        assert retval == expected_retval
+        return eyed3.load(audiofile.path, tag_version=reload_version)
+
+    return func
+
